title: Subpage in subdirectory
---

This page is deeper in the hierarchy. You can use `|page|` in URLs to
link to other places in the page hierarchy, [such as this other
subpage](|page|/subpage1.html)

You can link to the API documentation with the Ford `[[link]]` style:
[[ford_test_program]]
